@@ -1,6 +1,8 @@
+from typing import Any, Dict
+
 import jwt
-from typing import Dict, Any, List
-from revjwt.cert import stg_cert, prod_cert
+
+from revjwt.cert import prod_cert, stg_cert
 
 
 class RevJWKClient(jwt.PyJWKClient):
